==> static-compat-qt6-declarative-6.7.3-1-x86_64.pkg.tar.zst: usr/static-compat/lib/cmake/Qt6Qml/QmlPlugins/Qt6qtquickcontrols2nativestylepluginTargets-release.cmake <==
#----------------------------------------------------------------
# Generated CMake target import file for configuration "Release".
#----------------------------------------------------------------

# Commands may need to know the format version.
set(CMAKE_IMPORT_FILE_VERSION 1)

# Import target "Qt6::qtquickcontrols2nativestyleplugin" for configuration "Release"
set_property(TARGET Qt6::qtquickcontrols2nativestyleplugin APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(Qt6::qtquickcontrols2nativestyleplugin PROPERTIES
  IMPORTED_LINK_INTERFACE_LANGUAGES_RELEASE "CXX"
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib/qt6/qml/QtQuick/NativeStyle/libqtquickcontrols2nativestyleplugin.a"
  )

list(APPEND _cmake_import_check_targets Qt6::qtquickcontrols2nativestyleplugin )
list(APPEND _cmake_import_check_files_for_Qt6::qtquickcontrols2nativestyleplugin "${_IMPORT_PREFIX}/lib/qt6/qml/QtQuick/NativeStyle/libqtquickcontrols2nativestyleplugin.a" )

# Import target "Qt6::qtquickcontrols2nativestyleplugin_resources_1" for configuration "Release"
set_property(TARGET Qt6::qtquickcontrols2nativestyleplugin_resources_1 APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(Qt6::qtquickcontrols2nativestyleplugin_resources_1 PROPERTIES
  IMPORTED_COMMON_LANGUAGE_RUNTIME_RELEASE ""
  IMPORTED_OBJECTS_RELEASE "${_IMPORT_PREFIX}/lib/qt6/qml/QtQuick/NativeStyle/objects-Release/qtquickcontrols2nativestyleplugin_resources_1/.qt/rcc/qrc_qmake_QtQuick_NativeStyle_init.cpp.o"
  )

list(APPEND _cmake_import_check_targets Qt6::qtquickcontrols2nativestyleplugin_resources_1 )
list(APPEND _cmake_import_check_files_for_Qt6::qtquickcontrols2nativestyleplugin_resources_1 "${_IMPORT_PREFIX}/lib/qt6/qml/QtQuick/NativeStyle/objects-Release/qtquickcontrols2nativestyleplugin_resources_1/.qt/rcc/qrc_qmake_QtQuick_NativeStyle_init.cpp.o" )

# Import target "Qt6::qtquickcontrols2nativestyleplugin_resources_2" for configuration "Release"
set_property(TARGET Qt6::qtquickcontrols2nativestyleplugin_resources_2 APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(Qt6::qtquickcontrols2nativestyleplugin_resources_2 PROPERTIES
  IMPORTED_COMMON_LANGUAGE_RUNTIME_RELEASE ""
  IMPORTED_OBJECTS_RELEASE "${_IMPORT_PREFIX}/lib/qt6/qml/QtQuick/NativeStyle/objects-Release/qtquickcontrols2nativestyleplugin_resources_2/.qt/rcc/qrc_qtquickcontrols2nativestyleplugin_raw_qml_0_init.cpp.o"
  )

list(APPEND _cmake_import_check_targets Qt6::qtquickcontrols2nativestyleplugin_resources_2 )
list(APPEND _cmake_import_check_files_for_Qt6::qtquickcontrols2nativestyleplugin_resources_2 "${_IMPORT_PREFIX}/lib/qt6/qml/QtQuick/NativeStyle/objects-Release/qtquickcontrols2nativestyleplugin_resources_2/.qt/rcc/qrc_qtquickcontrols2nativestyleplugin_raw_qml_0_init.cpp.o" )

# Import target "Qt6::qtquickcontrols2nativestyleplugin_init" for configuration "Release"
set_property(TARGET Qt6::qtquickcontrols2nativestyleplugin_init APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(Qt6::qtquickcontrols2nativestyleplugin_init PROPERTIES
  IMPORTED_COMMON_LANGUAGE_RUNTIME_RELEASE ""
  IMPORTED_OBJECTS_RELEASE "${_IMPORT_PREFIX}/lib/qt6/qml/QtQuick/NativeStyle/objects-Release/qtquickcontrols2nativestyleplugin_init/qtquickcontrols2nativestyleplugin_init.cpp.o"
  )

list(APPEND _cmake_import_check_targets Qt6::qtquickcontrols2nativestyleplugin_init )
list(APPEND _cmake_import_check_files_for_Qt6::qtquickcontrols2nativestyleplugin_init "${_IMPORT_PREFIX}/lib/qt6/qml/QtQuick/NativeStyle/objects-Release/qtquickcontrols2nativestyleplugin_init/qtquickcontrols2nativestyleplugin_init.cpp.o" )

# Commands beyond this point should not need to know the version.
set(CMAKE_IMPORT_FILE_VERSION)

==> static-compat-qt6-declarative-6.8.0-1-x86_64.pkg.tar.zst: usr/static-compat/lib/cmake/Qt6Qml/QmlPlugins/Qt6qtquickcontrols2nativestylepluginTargets-release.cmake <==
#----------------------------------------------------------------
# Generated CMake target import file for configuration "Release".
#----------------------------------------------------------------

# Commands may need to know the format version.
set(CMAKE_IMPORT_FILE_VERSION 1)

# Import target "Qt6::qtquickcontrols2nativestyleplugin" for configuration "Release"
set_property(TARGET Qt6::qtquickcontrols2nativestyleplugin APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(Qt6::qtquickcontrols2nativestyleplugin PROPERTIES
  IMPORTED_LINK_INTERFACE_LANGUAGES_RELEASE "CXX"
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib/qt6/qml/QtQuick/NativeStyle/libqtquickcontrols2nativestyleplugin.a"
  )

list(APPEND _cmake_import_check_targets Qt6::qtquickcontrols2nativestyleplugin )
list(APPEND _cmake_import_check_files_for_Qt6::qtquickcontrols2nativestyleplugin "${_IMPORT_PREFIX}/lib/qt6/qml/QtQuick/NativeStyle/libqtquickcontrols2nativestyleplugin.a" )

# Import target "Qt6::qtquickcontrols2nativestyleplugin_resources_1" for configuration "Release"
set_property(TARGET Qt6::qtquickcontrols2nativestyleplugin_resources_1 APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(Qt6::qtquickcontrols2nativestyleplugin_resources_1 PROPERTIES
  IMPORTED_COMMON_LANGUAGE_RUNTIME_RELEASE ""
  IMPORTED_OBJECTS_RELEASE "${_IMPORT_PREFIX}/lib/qt6/qml/QtQuick/NativeStyle/objects-Release/qtquickcontrols2nativestyleplugin_resources_1/.qt/rcc/qrc_qmake_QtQuick_NativeStyle_init.cpp.o"
  )

list(APPEND _cmake_import_check_targets Qt6::qtquickcontrols2nativestyleplugin_resources_1 )
list(APPEND _cmake_import_check_files_for_Qt6::qtquickcontrols2nativestyleplugin_resources_1 "${_IMPORT_PREFIX}/lib/qt6/qml/QtQuick/NativeStyle/objects-Release/qtquickcontrols2nativestyleplugin_resources_1/.qt/rcc/qrc_qmake_QtQuick_NativeStyle_init.cpp.o" )

# Import target "Qt6::qtquickcontrols2nativestyleplugin_resources_2" for configuration "Release"
set_property(TARGET Qt6::qtquickcontrols2nativestyleplugin_resources_2 APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(Qt6::qtquickcontrols2nativestyleplugin_resources_2 PROPERTIES
  IMPORTED_COMMON_LANGUAGE_RUNTIME_RELEASE ""
  IMPORTED_OBJECTS_RELEASE "${_IMPORT_PREFIX}/lib/qt6/qml/QtQuick/NativeStyle/objects-Release/qtquickcontrols2nativestyleplugin_resources_2/.qt/rcc/qrc_qtquickcontrols2nativestyleplugin_raw_qml_0_init.cpp.o"
  )

list(APPEND _cmake_import_check_targets Qt6::qtquickcontrols2nativestyleplugin_resources_2 )
list(APPEND _cmake_import_check_files_for_Qt6::qtquickcontrols2nativestyleplugin_resources_2 "${_IMPORT_PREFIX}/lib/qt6/qml/QtQuick/NativeStyle/objects-Release/qtquickcontrols2nativestyleplugin_resources_2/.qt/rcc/qrc_qtquickcontrols2nativestyleplugin_raw_qml_0_init.cpp.o" )

# Import target "Qt6::qtquickcontrols2nativestyleplugin_resources_3" for configuration "Release"
set_property(TARGET Qt6::qtquickcontrols2nativestyleplugin_resources_3 APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(Qt6::qtquickcontrols2nativestyleplugin_resources_3 PROPERTIES
  IMPORTED_COMMON_LANGUAGE_RUNTIME_RELEASE ""
  IMPORTED_OBJECTS_RELEASE "${_IMPORT_PREFIX}/lib/qt6/qml/QtQuick/NativeStyle/objects-Release/qtquickcontrols2nativestyleplugin_resources_3/.qt/rcc/qrc_qtquickcontrols2nativestyleplugin_raw_qml_0_extra_qmldirs_init.cpp.o"
  )

list(APPEND _cmake_import_check_targets Qt6::qtquickcontrols2nativestyleplugin_resources_3 )
list(APPEND _cmake_import_check_files_for_Qt6::qtquickcontrols2nativestyleplugin_resources_3 "${_IMPORT_PREFIX}/lib/qt6/qml/QtQuick/NativeStyle/objects-Release/qtquickcontrols2nativestyleplugin_resources_3/.qt/rcc/qrc_qtquickcontrols2nativestyleplugin_raw_qml_0_extra_qmldirs_init.cpp.o" )

# Import target "Qt6::qtquickcontrols2nativestyleplugin_init" for configuration "Release"
set_property(TARGET Qt6::qtquickcontrols2nativestyleplugin_init APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(Qt6::qtquickcontrols2nativestyleplugin_init PROPERTIES
  IMPORTED_COMMON_LANGUAGE_RUNTIME_RELEASE ""
  IMPORTED_OBJECTS_RELEASE "${_IMPORT_PREFIX}/lib/qt6/qml/QtQuick/NativeStyle/objects-Release/qtquickcontrols2nativestyleplugin_init/qtquickcontrols2nativestyleplugin_init.cpp.o"
  )

list(APPEND _cmake_import_check_targets Qt6::qtquickcontrols2nativestyleplugin_init )
list(APPEND _cmake_import_check_files_for_Qt6::qtquickcontrols2nativestyleplugin_init "${_IMPORT_PREFIX}/lib/qt6/qml/QtQuick/NativeStyle/objects-Release/qtquickcontrols2nativestyleplugin_init/qtquickcontrols2nativestyleplugin_init.cpp.o" )

# Commands beyond this point should not need to know the version.
set(CMAKE_IMPORT_FILE_VERSION)
